@@ -150,9 +150,9 @@ def setup(**settings_patches):
     sshd_config = '/etc/ssh/sshd_config'
     new_lines = [
         'Match Group beanstalk',
-        '       ForceCommand /home/beanstalk/check_user',
+        '       ForceCommand /usr/bin/bs_ssh_entry',
     ]
-    local(sed('$a\\{command}'.format(command='\\n'.join(new_lines)), sshd_config))
+    local(sed('$a\\\n{command}'.format(command='\n'.join(new_lines)), sshd_config))
     local(sed('s/^AllowGroups (.*)$/AllowGroups \\1 beanstalk/g', sshd_config, '-E'))
 
     # Apache conf
